@@ -32,31 +32,6 @@ class CityPowerError(Exception):
     pass
 
 
-class Province(Enum):
-    EASTERN_CAPE = 1
-    FREE_STATE = 2
-    GAUTENG = 3
-    KWAZULU_NATAL = 4
-    LIMPOPO = 6
-    MPUMALANGA = 5
-    NORTH_WEST = 7
-    NORTERN_CAPE = 8
-    WESTERN_CAPE = 9
-
-    def __str__(self):
-        return {
-            self.EASTERN_CAPE: "Eastern Cape",
-            self.FREE_STATE: "Free State",
-            self.GAUTENG: "Gauteng",
-            self.KWAZULU_NATAL: "Kwa-Zulu Natal",
-            self.LIMPOPO: "Limpopo",
-            self.MPUMALANGA: "Mpumalanga",
-            self.NORTH_WEST: "North West",
-            self.NORTERN_CAPE: "Nortern Cape",
-            self.WESTERN_CAPE: "Western Cape",
-        }.get(self, "Unknown Province")
-
-
 base_url = "https://www.citypower.co.za"
 
 
@@ -112,7 +87,10 @@ def parse_stage_forecast(data: str) -> Dict:
                         break
                     next_stage["end_time"] = end_time
                 if c == 4:
-                    next_stage["stage"] = int(text)
+                    try:
+                        next_stage["stage"] = int(text)
+                    except ValueError as err:
+                        next_stage["stage"] = 0
             if next_stage:
                 forecast.append(next_stage)
     except Exception as e:
